@@ -1,5 +1,5 @@
 package Data::Faker;
-use vars qw($VERSION); $VERSION = '0.10_04';
+use vars qw($VERSION); $VERSION = '0.07';
 
 =head1 NAME
 
@@ -14,7 +14,7 @@ Data::Faker - Perl extension for generating fake data
   print "Name:    ".$faker->name."\n";
   print "Company: ".$faker->company."\n";
   print "Address: ".$faker->street_address."\n";
-  print "         ".$faker->city.", ".$faker->us_state_abbr." ".$faker->us_zip_code."\n";
+  print "         ".$faker->city.", ".$faker->state." ".$faker->zip."\n";
 
 =head1 DESCRIPTION
 
@@ -70,7 +70,7 @@ plugins.
 
 =cut
 
-sub methods { return keys %Data::Faker::plugins; }
+sub methods { return keys %Data::Faker::plugins; } 
 
 =item register_plugin();
 
@@ -121,7 +121,7 @@ sub AUTOLOAD {
 	$result =~ s/\\#/\0/g;
 	$result =~ s/#/int(rand(10))/ge;
 	$result =~ s/\0/#/g;
-
+	
 	return $result;
 }
 
@@ -211,7 +211,7 @@ Jason Kohles, E<lt>email@jasonkohles.comE<gt>
 Copyright 2004-2005 by Jason Kohles
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the same terms as Perl itself. 
 
 =cut
 
