@@ -1,7 +1,5 @@
 package Data::Faker::DateTime;
-use strict;
-use warnings;
-use vars qw($VERSION); $VERSION = '0.10_04';
+use vars qw($VERSION); $VERSION = '0.07';
 use base 'Data::Faker';
 use POSIX;
 
@@ -230,15 +228,10 @@ your system.
 
 =cut
 
-{
-    # timestr here redefines the one from Benchmark, which is only loaded for tests.
-    no warnings 'redefine';
-
-    sub timestr {
-        my $format = shift;
-        if(ref($format)) { $format = shift }
-        POSIX::strftime($format, localtime(__PACKAGE__->unixtime));
-    }
+sub timestr {
+	my $format = shift;
+	if(ref($format)) { $format = shift }
+	POSIX::strftime($format,localtime(__PACKAGE__->unixtime));
 }
 
 =back
@@ -247,7 +240,7 @@ your system.
 
 =over 4
 
-=item Be careful building timestamps from pieces
+=item Be careful build timestamps from pieces
 
 Be very careful about building date/time representations in formats that
 are not already listed here.  For example if you wanted to get a date that
